@@ -1,7 +1,7 @@
 package App::dateseq;
 
 our $DATE = '2019-07-16'; # DATE
-our $VERSION = '0.095'; # VERSION
+our $VERSION = '0.096'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,7 +28,7 @@ _
             summary => 'Starting date',
             schema => ['date*', {
                 'x.perl.coerce_to' => 'DateTime',
-                'x.perl.coerce_rules' => ['str_alami_en'],
+                'x.perl.coerce_rules' => ['str_natural'],
             }],
             pos => 0,
         },
@@ -36,7 +36,7 @@ _
             summary => 'End date, if not specified will generate an infinite* stream of dates',
             schema => ['date*', {
                 'x.perl.coerce_to' => 'DateTime',
-                'x.perl.coerce_rules' => ['str_alami_en'],
+                'x.perl.coerce_rules' => ['str_natural'],
             }],
             pos => 1,
         },
@@ -286,9 +286,10 @@ sub dateseq {
         push @res, $args{header} if $args{header};
         my $dt = $args{from}->clone;
         while (1) {
+            #say "D:$dt vs $args{to}? ", DateTime->compare($dt, $args{to});
             if (defined $args{to}) {
-                last if  $reverse && DateTime->compare($dt, $args{to}) <  0;
-                last if !$reverse && DateTime->compare($dt, $args{to}) >= 0;
+                last if !$reverse && DateTime->compare($dt, $args{to}) > 0;
+                last if  $reverse && DateTime->compare($dt, $args{to}) < 0;
             }
             push @res, $strp->format_datetime($dt) if $code_filter->($dt);
             last if defined($args{limit}) && @res >= $args{limit};
@@ -337,7 +338,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.095 of App::dateseq (from Perl distribution App-dateseq), released on 2019-07-16.
+This document describes version 0.096 of App::dateseq (from Perl distribution App-dateseq), released on 2019-07-16.
 
 =head1 FUNCTIONS
 
